%define major     9
%define libname   %mklibname rocksdb %{major}
%define develname %mklibname rocksdb -d

Name:       rocksdb
Version:    9.10.0
Release:    %mkrel 1
Summary:    A Persistent Key-Value Store for Flash and RAM Storage
Group:      Databases
License:    BSD
URL:        https://github.com/facebook/rocksdb
Source0:    https://github.com/facebook/rocksdb/archive/v%{version}/%{name}-%{version}.tar.gz
#(wally) use system gtest
Patch2:     rocksdb-gtest.patch
# From Fedora
Patch10:    disable-static.patch
# From Alpine Linux via Fedora
Patch11:    shared-liburing.patch
# From Debian via Fedora
Patch13:    no_rpath.patch

BuildRequires: cmake
BuildRequires: pkgconfig(gtest)
BuildRequires: pkgconfig(gflags)
BuildRequires: pkgconfig(liburing)
# for compression
BuildRequires: pkgconfig(bzip2)
BuildRequires: pkgconfig(liblz4)
BuildRequires: pkgconfig(snappy)
BuildRequires: pkgconfig(zlib)
BuildRequires: pkgconfig(libzstd)

ExcludeArch: %{arm}

%description
Rocksdb is a library that forms the core building block for a fast key value
server, especially suited for storing data on flash drives. It has a
Log-Structured-Merge-Database (LSM) design with flexible trade offs between
Write-Amplification-Factor (WAF), Read-Amplification-Factor (RAF) and
Space-Amplification-Factor (SAF). It has multithreaded compaction, making it
specially suitable for storing multiple terabytes of data in a single database.

%package -n %{libname}
Summary:    A Persistent Key-Value Store for Flash and RAM Storage
Group:      Databases
Provides:   %{name} = %{version}-%{release}
Obsoletes:  %{_lib}rocksdb8 < 8.11.3-4
Obsoletes:  %{_lib}rocksdb9.5 < 9.5.2-2

%description -n %{libname}
Rocksdb is a library that forms the core building block for a fast key value
server, especially suited for storing data on flash drives. It has a
Log-Structured-Merge-Database (LSM) design with flexible trade offs between
Write-Amplification-Factor (WAF), Read-Amplification-Factor (RAF) and
Space-Amplification-Factor (SAF). It has multithreaded compaction, making it
specially suitable for storing multiple terabytes of data in a single database.

%package -n %{develname}
Summary:    Development files for rocksdb
Group:      Development/C
Requires:   %{libname} = %{version}-%{release}
Provides:   rocksdb-devel = %{version}-%{release}
Provides:   librocksdb-devel = %{version}-%{release}

%description -n %{develname}
Development files for rocksdb.

%prep
%autosetup -p1

rm -rf third-party/gtest-*
rm java/benchmark/src/main/java/org/rocksdb/benchmark/DbBenchmark.java
rm build_tools/gnu_parallel

%build
#(eatdirt) RTTI necessary for ceph
%cmake -DPORTABLE=ON \
       -DUSE_RTTI=ON \
       -DFAIL_ON_WARNINGS=OFF \
       -DROCKSDB_BUILD_SHARED=ON \
       -DWITH_TOOLS=OFF \
       -DWITH_TRACE_TOOLS=OFF \
       -DWITH_ALL_TESTS=OFF \
       -DWITH_BZ2=ON \
       -DWITH_SNAPPY=ON \
       -DWITH_LZ4=ON \
       -DWITH_ZSTD=ON \
       -DWITH_ZLIB=ON

%cmake_build

%install
%cmake_install


%files -n %{libname}
%{_libdir}/librocksdb.so.%{major}{,.*}
%license COPYING LICENSE.Apache LICENSE.leveldb


%files -n %{develname}
%doc README.md HISTORY.md LANGUAGE-BINDINGS.md
%{_libdir}/librocksdb.so
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/cmake/rocksdb


%changelog
* Fri Jan 03 2025 daviddavid <daviddavid> 9.10.0-1.mga10
+ Revision: 2135061
- new version: 9.10.0
- use a single libmajor as upstream
- enable some compression support

* Fri Sep 06 2024 eatdirt <eatdirt> 9.5.2-1.mga10
+ Revision: 2093413
- Upgrade to version 9.5.2

* Sat Apr 27 2024 wally <wally> 8.11.4-1.mga10
+ Revision: 2061313
- new version 8.11.4

* Sat Apr 13 2024 wally <wally> 8.11.3-4.mga10
+ Revision: 2056887
- fix lib major and lib pkg name
- drop unneeded i686 build fix patch
- add patch to use system gtest
- add patches via Fedora to fix build
- use portable build to skip -march=native
+ eatdirt <eatdirt>
- Move build system to cmake

* Sat Apr 13 2024 wally <wally> 8.11.3-3.mga10
+ Revision: 2056796
- fix build on i686
+ eatdirt <eatdirt>
- Update to version 8.11.3

* Tue Mar 19 2024 joequant <joequant> 8.10.0-1.mga10
+ Revision: 2050608
- update to 8.10.0

* Thu Apr 06 2023 eatdirt <eatdirt> 7.7.8-1.mga9
+ Revision: 1951574
- Update to latest bugfix release of the same major version

* Sun Nov 20 2022 joequant <joequant> 7.7.3-1.mga9
+ Revision: 1909145
- update to 7.7.3

* Mon Oct 03 2022 joequant <joequant> 7.6.0-1.mga9
+ Revision: 1894345
- update to 7.6.0

* Tue Aug 23 2022 eatdirt <eatdirt> 7.4.5-1.mga9
+ Revision: 1879641
- Upgrade to version 7.4.5

* Tue Mar 29 2022 umeabot <umeabot> 6.26.1-3.mga9
+ Revision: 1833296
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 pterjan <pterjan> 6.26.1-2.mga9
+ Revision: 1783159
- Restrict to support architectures

* Mon Dec 13 2021 joequant <joequant> 6.26.1-1.mga9
+ Revision: 1761864
- update to 6.23.1

* Sun Dec 12 2021 eatdirt <eatdirt> 6.25.3-1.mga9
+ Revision: 1761657
- Upgrade to bugfix release 6.25.3

* Wed Oct 20 2021 joequant <joequant> 6.25.1-1.mga9
+ Revision: 1752290
- update to 6.25.1

* Fri Jun 18 2021 joequant <joequant> 6.20.3-1.mga9
+ Revision: 1731159
- update to 6.20.3

* Fri Dec 18 2020 joequant <joequant> 6.14.6-1.mga8
+ Revision: 1660881
- update to 6.14.6

* Wed Aug 26 2020 eatdirt <eatdirt> 6.11.4-3.mga8
+ Revision: 1619161
- Link to -ldl
- Force PORTABLE=1 to not trigger SSE4 instructions

* Fri Aug 21 2020 eatdirt <eatdirt> 6.11.4-2.mga8
+ Revision: 1617546
- Rebuild with USE_RTTI=1 (in prep for ceph)

* Thu Aug 20 2020 eatdirt <eatdirt> 6.11.4-1.mga8
+ Revision: 1616614
- Upgrade to version 6.11.4, add missing provides

* Sat Feb 15 2020 daviddavid <daviddavid> 6.6.4-1.mga8
+ Revision: 1527307
- new version: 6.6.4
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Sat Jul 06 2019 joequant <joequant> 6.1.2-1.mga8
+ Revision: 1418909
- update version

* Sat Jul 06 2019 joequant <joequant> 5.17.2-1.mga8
+ Revision: 1418871
- add group
- add group
- imported package rocksdb

